==> imkit-anthy-0.3.3.tar.gz: imkit-anthy-0.3.3/imwidget_std.h <==
// IMKit-Anthy: A Qtopia InputMethod interface for Anthy
// Copyright (C) 2002  YamaKen <yamaken@bp.iij4u.or.jp>
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

// $Name: IMKIT_ANTHY_0_3_3 $
// $Id: imwidget_std.h,v 1.34 2002/07/12 11:51:46 yamaken Exp $

#ifndef IMKIT_IMWIDGET_STD_H
#define IMKIT_IMWIDGET_STD_H

#include <qlineedit.h>
#include <qcombobox.h>
#include <qlistbox.h>
#include <qhbox.h>
#include "imwidget.h"


template <class Widget>
class PreeditWidgetAbstractor : public PreeditWidget {
protected:
  Widget *concrete_widget;

public:
  PreeditWidgetAbstractor(void);
  PreeditWidgetAbstractor(Widget *concrete_widget_init);
  virtual QWidget *widget(void);
  virtual void set_widget(Widget *new_widget);
  virtual void setCursorPosition(int new_position);
  virtual void setSelection(int focus_begin, int focus_length);
};


class StdPreedit : public Preedit {
  Q_OBJECT

protected:
  PreeditWidget *adaptee;
  QObject *inputmask_filter;
  PreeditState state;
  int _cursor_position;
  QString text;

protected:
  virtual bool eventFilter(QObject *receiver, QEvent *e);
  virtual bool on_paint_event(QWidget *receiver, QPaintEvent *e);
  virtual void connect_signals(void);
  virtual const char *separator_str(void);

signals:
  void cursor_position_changed(int new_position);
  void focus_changed(int focus_begin, int focus_length);
  void text_changed(const QString &new_text);
  void focus_position_changed(int x, int y);

public:
  StdPreedit(void);
  StdPreedit(PreeditWidget *adaptee_init);
  virtual ~StdPreedit(void);
  virtual QWidget *widget(void);
  virtual void set_widget(PreeditWidget *new_adaptee);
  virtual int cursor_position(void);
  virtual void set_cursor_position(int new_position);
  virtual void set_focus(int focus_begin, int focus_length);
  virtual void set_text(const QString &new_text);

public slots:
  virtual void update_state(PreeditState new_state);
  virtual void update(Segments &segments);
};


template <class Widget>
class InputMapIndicatorWidgetAbstractor : public InputMapIndicatorWidget {
protected:
  Widget *concrete_widget;

public:
  InputMapIndicatorWidgetAbstractor(void);
  InputMapIndicatorWidgetAbstractor(Widget *concrete_widget_init);
  virtual QWidget *widget(void);
  virtual void set_widget(Widget *new_widget);
  virtual void setCurrentItem(int index);
  virtual void insertItem(const QString &label, int index);
};


class StdInputMapIndicator : public InputMapIndicator {
  Q_OBJECT

protected:
  InputMapIndicatorWidget *adaptee;
  InputMap _state;
  int n_state;
  BidirMap<int, InputMap> n2a_map_code;

protected:
  virtual void connect_signals(void);

public:
  StdInputMapIndicator(void);
  StdInputMapIndicator(InputMapIndicatorWidget *adaptee_init);
  virtual ~StdInputMapIndicator(void);
  virtual QWidget *widget(void);
  virtual void set_widget(InputMapIndicatorWidget *new_adaptee);
  virtual InputMap state(void) const;
  virtual void add_state(InputMap map_code, const QString &label);

signals:
  void selected(InputMap new_state);

protected slots:
  virtual void select_by_adaptee(int index);

public:
  virtual void select(InputMap new_state);
};


class CandidateWindowWidget
//: virtual public QWidget  //Qt2ǤϥݡȤƤʤ
{
public:
  virtual QWidget *widget(void) = 0;  // : virtual public QWidget
  virtual void clear(void) = 0;
  virtual void insertItem(const QString &item) = 0;
  virtual void setCurrentItem(int index) = 0;
  virtual void setTopItem(int index) = 0;
  virtual void setBottomItem(int index) = 0;

  //TODO: QListBoxItem˰¸ʤ褦ˤ
  virtual int index(const QListBoxItem *item) = 0;
};


template <class Widget>
class CandidateWindowWidgetAbstractor : public CandidateWindowWidget {
protected:
  Widget *concrete_widget;

public:
  CandidateWindowWidgetAbstractor(void);
  CandidateWindowWidgetAbstractor(Widget *widget_init);
  virtual QWidget *widget(void);
  virtual void set_widget(Widget *new_widget);
  virtual void clear(void);
  virtual void insertItem(const QString &item);
  virtual void setCurrentItem(int index);
  virtual void setTopItem(int index);
  virtual void setBottomItem(int index);
  virtual int index(const QListBoxItem *item);
};


class StdCandidateWindow
  : public CandidateWindow, public ActivatableQWidgetAdapter
{
  Q_OBJECT

protected:
  CandidateWindowWidget *adaptee;
  Candidates::size_type index, n_candidates;

protected:
  virtual void connect_signals(void);

protected slots:
  virtual void select_by_widget(QListBoxItem *selected_item);
  virtual void select_by_widget(int new_index);

public:
  StdCandidateWindow(void);
  StdCandidateWindow(CandidateWindowWidget *adaptee_init);
  virtual ~StdCandidateWindow(void);
  virtual QWidget *widget(void);
  virtual void set_widget(CandidateWindowWidget *new_adaptee);

public slots:
  virtual void slot_activate(bool activity);
  virtual void update(Candidates &new_candidates);
  virtual void hilight(int selected, bool reversely);
  virtual void move_above(int x, int y);
};


#ifndef IMKIT_USE_TEMPLATE_QOBJECT

class StdIMWidget : public QHBox {
  Q_OBJECT

public:
  inline StdIMWidget(QWidget *parent = 0,
                     const char *name = 0, WFlags flags = 0)
    : QHBox(parent, name, flags)
  {}

#ifndef IMKIT_COMPILE_WITH_PREPROCESSABLE_MOC
protected:
  virtual void showEvent(QShowEvent *e);
  virtual void hideEvent(QHideEvent *e);
signals:
  void activated(bool activity);
#else
  IMKIT_DECLARE_ACTIVATED_SIGNALS_FOR_QWIDGET;
#endif
};

#endif  //IMKIT_USE_TEMPLATE_QOBJECT

//////////////////////////////////////////////////////////////////////////////

template <class Widget>
PreeditWidgetAbstractor<Widget>::PreeditWidgetAbstractor(void)
  : concrete_widget(NULL)
{
}

template <class Widget>
PreeditWidgetAbstractor<Widget>::
PreeditWidgetAbstractor(Widget *concrete_widget_init)
  : concrete_widget(NULL)
{
  set_widget(concrete_widget_init);
}

template <class Widget>
QWidget *
PreeditWidgetAbstractor<Widget>::widget(void) {
  return concrete_widget;
}

template <class Widget>
void
PreeditWidgetAbstractor<Widget>::set_widget(Widget *new_widget) {
  concrete_widget = new_widget;
}

template <class Widget>
void
PreeditWidgetAbstractor<Widget>::setCursorPosition(int new_position) {
  //(concrete_widget->hasFocus() == true)¸ʤưʤǤ
  //QLineEditǤ̵
  concrete_widget->setCursorPosition(new_position);
}

template <class Widget>
void
PreeditWidgetAbstractor<Widget>::
setSelection(int focus_begin, int focus_length) {
  //եɽȴǼ¸뤿selectionήѤ
  concrete_widget->setSelection(focus_begin, focus_length);
}

template <class Widget>
InputMapIndicatorWidgetAbstractor<Widget>::
InputMapIndicatorWidgetAbstractor(void)
  : concrete_widget(NULL)
{
}

template <class Widget>
InputMapIndicatorWidgetAbstractor<Widget>::
InputMapIndicatorWidgetAbstractor(Widget *concrete_widget_init)
  : concrete_widget(NULL)
{
  set_widget(concrete_widget_init);
}

template <class Widget>
QWidget *
InputMapIndicatorWidgetAbstractor<Widget>::widget(void) {
  return concrete_widget;
}

template <class Widget>
void
InputMapIndicatorWidgetAbstractor<Widget>::set_widget(Widget *new_widget) {
  concrete_widget = new_widget;
}

template <class Widget>
void
InputMapIndicatorWidgetAbstractor<Widget>::setCurrentItem(int index) {
  concrete_widget->setCurrentItem(index);
}

template <class Widget>
void
InputMapIndicatorWidgetAbstractor<Widget>::
insertItem(const QString &label, int index) {
  concrete_widget->insertItem(label, index);
}


template <class Widget>
CandidateWindowWidgetAbstractor<Widget>::CandidateWindowWidgetAbstractor(void)
  : concrete_widget(NULL)
{
}

template <class Widget>
CandidateWindowWidgetAbstractor<Widget>::
CandidateWindowWidgetAbstractor(Widget *widget_init) {
  set_widget(widget_init);
}

template <class Widget>
QWidget *
CandidateWindowWidgetAbstractor<Widget>::widget(void) {
  return concrete_widget;
}

template <class Widget>
void
CandidateWindowWidgetAbstractor<Widget>::set_widget(Widget *new_widget) {
  concrete_widget = new_widget;
}

template <class Widget>
void
CandidateWindowWidgetAbstractor<Widget>::clear(void) {
  concrete_widget->clear();
}

template <class Widget>
void
CandidateWindowWidgetAbstractor<Widget>::insertItem(const QString &item) {
  concrete_widget->insertItem(item);
}

template <class Widget>
void
CandidateWindowWidgetAbstractor<Widget>::setCurrentItem(int index) {
  concrete_widget->setCurrentItem(index);
}

template <class Widget>
void
CandidateWindowWidgetAbstractor<Widget>::setTopItem(int index) {
  concrete_widget->setTopItem(index);
}

template <class Widget>
void
CandidateWindowWidgetAbstractor<Widget>::setBottomItem(int index) {
  concrete_widget->setBottomItem(index);
}

template <class Widget>
int
CandidateWindowWidgetAbstractor<Widget>::index(const QListBoxItem *item) {
  return concrete_widget->index(item);
}


#endif  //IMKIT_IMWIDGET_STD_H

==> imkit-anthy-0.3.4.tar.gz: imkit-anthy-0.3.4/imwidget_std.h <==
// IMKit-Anthy: A Qtopia InputMethod interface for Anthy
// Copyright (C) 2002  YamaKen <yamaken@bp.iij4u.or.jp>
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

// $Name: IMKIT_ANTHY_0_3_4 $
// $Id: imwidget_std.h,v 1.39 2002/08/05 02:20:33 yamaken Exp $

#ifndef IMKIT_IMWIDGET_STD_H
#define IMKIT_IMWIDGET_STD_H

#include <qcombobox.h>
#include <qlistbox.h>
#include <qhbox.h>
#include "imwidget.h"


template <class Widget>
class PreeditWidgetAbstractor : public PreeditWidget {
protected:
  Widget *concrete_widget;

public:
  PreeditWidgetAbstractor(void);
  PreeditWidgetAbstractor(Widget *concrete_widget_init);
  virtual QWidget *widget(void);
  virtual void set_widget(Widget *new_widget);
  virtual void setCursorPosition(int new_position);
  virtual void setSelection(int focus_begin, int focus_length);

//public slots:
//  void setText(const QString &);

//signals:
//  void selected(const QRect &selection);
};


class StdPreedit : public Preedit {
  Q_OBJECT

protected:
  PreeditWidget *adaptee;
  QObject *inputmask_filter;
  PreeditState state;
  int _cursor_position;
  QString _separator_str;
  QString text;

protected:
  virtual void connect_signals(void);
  virtual const QString &separator_str(void);

signals:
  void cursor_position_changed(int new_position);
  void focus_changed(int focus_begin, int focus_length);
  void text_changed(const QString &new_text);
  void focus_changed(const QRect &abs_focus);

public:
  StdPreedit(const QString &separator_str_init = "|");
  StdPreedit(PreeditWidget *adaptee_init,
             const QString &separator_str_init = "|");
  virtual ~StdPreedit(void);
  virtual QWidget *widget(void);
  virtual void set_widget(PreeditWidget *new_adaptee);
  virtual int cursor_position(void);
  virtual void set_cursor_position(int new_position);
  virtual void set_focus(int focus_begin, int focus_length);
  virtual void set_text(const QString &new_text);
  virtual void set_separator_str(const QString &new_separator_str = "|");

public slots:
  virtual void update_state(PreeditState new_state);
  virtual void update(Segments &segments);
  virtual void select(const QRect &selection);
};


template <class Widget>
class InputMapIndicatorWidgetAbstractor : public InputMapIndicatorWidget {
protected:
  Widget *concrete_widget;

public:
  InputMapIndicatorWidgetAbstractor(void);
  InputMapIndicatorWidgetAbstractor(Widget *concrete_widget_init);
  virtual QWidget *widget(void);
  virtual void set_widget(Widget *new_widget);
  virtual void setCurrentItem(int index);
  virtual void insertItem(const QString &label, int index);
};


class StdInputMapIndicator : public InputMapIndicator {
  Q_OBJECT

protected:
  InputMapIndicatorWidget *adaptee;
  InputMap _state;
  int n_state;
  BidirMap<int, InputMap> n2a_map_code;

protected:
  virtual void connect_signals(void);

public:
  StdInputMapIndicator(void);
  StdInputMapIndicator(InputMapIndicatorWidget *adaptee_init);
  virtual ~StdInputMapIndicator(void);
  virtual QWidget *widget(void);
  virtual void set_widget(InputMapIndicatorWidget *new_adaptee);
  virtual InputMap state(void) const;
  virtual void add_state(InputMap map_code, const QString &label);

signals:
  void selected(InputMap new_state);

protected slots:
  virtual void select_by_adaptee(int index);

public:
  virtual void select(InputMap new_state);
};


class CandidateWindowWidget
//: virtual public QWidget  //Qt2ǤϥݡȤƤʤ
{
public:
  virtual QWidget *widget(void) = 0;  // : virtual public QWidget
  virtual void clear(void) = 0;
  virtual void insertItem(const QString &item) = 0;
  virtual void setCurrentItem(int index) = 0;
  virtual void setTopItem(int index) = 0;
  virtual void setBottomItem(int index) = 0;

  //TODO: QListBoxItem˰¸ʤ褦ˤ
  virtual int index(const QListBoxItem *item) = 0;
};


template <class Widget>
class CandidateWindowWidgetAbstractor : public CandidateWindowWidget {
protected:
  Widget *concrete_widget;

public:
  CandidateWindowWidgetAbstractor(void);
  CandidateWindowWidgetAbstractor(Widget *widget_init);
  virtual QWidget *widget(void);
  virtual void set_widget(Widget *new_widget);
  virtual void clear(void);
  virtual void insertItem(const QString &item);
  virtual void setCurrentItem(int index);
  virtual void setTopItem(int index);
  virtual void setBottomItem(int index);
  virtual int index(const QListBoxItem *item);
};


class StdCandidateWindow
  : public CandidateWindow, public ActivatableQWidgetAdapter
{
  Q_OBJECT

protected:
  CandidateWindowWidget *adaptee;
  Candidates::size_type index, n_candidates;

protected:
  virtual void connect_signals(void);

protected slots:
  virtual void select_by_widget(QListBoxItem *selected_item);
  virtual void select_by_widget(int new_index);

public:
  StdCandidateWindow(void);
  StdCandidateWindow(CandidateWindowWidget *adaptee_init);
  virtual ~StdCandidateWindow(void);
  virtual QWidget *widget(void);
  virtual void set_widget(CandidateWindowWidget *new_adaptee);

public slots:
  virtual void slot_activate(bool activity);
  virtual void update(Candidates &new_candidates);
  virtual void hilight(int selected, bool reversely);
  virtual void move_adjacent(const QRect &focus);
};


#ifndef IMKIT_USE_TEMPLATE_QOBJECT

class StdIMWidget : public QHBox {
  Q_OBJECT

public:
  inline StdIMWidget(QWidget *parent = 0,
                     const char *name = 0, WFlags flags = 0)
    : QHBox(parent, name, flags)
  {}

#ifndef IMKIT_COMPILE_WITH_PREPROCESSABLE_MOC
protected:
  virtual void showEvent(QShowEvent *e);
  virtual void hideEvent(QHideEvent *e);
signals:
  void activated(bool activity);
#else
  IMKIT_DECLARE_ACTIVATED_SIGNALS_FOR_QWIDGET;
#endif
};

#endif  //IMKIT_USE_TEMPLATE_QOBJECT


//////////////////////////////////////////////////////////////////////////////

template <class Widget>
PreeditWidgetAbstractor<Widget>::PreeditWidgetAbstractor(void)
  : concrete_widget(NULL)
{
}

template <class Widget>
PreeditWidgetAbstractor<Widget>::
PreeditWidgetAbstractor(Widget *concrete_widget_init)
  : concrete_widget(NULL)
{
  set_widget(concrete_widget_init);
}

template <class Widget>
QWidget *
PreeditWidgetAbstractor<Widget>::widget(void) {
  return concrete_widget;
}

template <class Widget>
void
PreeditWidgetAbstractor<Widget>::set_widget(Widget *new_widget) {
  concrete_widget = new_widget;
}

template <class Widget>
void
PreeditWidgetAbstractor<Widget>::setCursorPosition(int new_position) {
  //(concrete_widget->hasFocus() == true)¸ʤưʤǤ
  //QLineEditǤ̵
  concrete_widget->setCursorPosition(new_position);
}

template <class Widget>
void
PreeditWidgetAbstractor<Widget>::
setSelection(int focus_begin, int focus_length) {
  //եɽȴǼ¸뤿selectionήѤ
  concrete_widget->setSelection(focus_begin, focus_length);
}

template <class Widget>
InputMapIndicatorWidgetAbstractor<Widget>::
InputMapIndicatorWidgetAbstractor(void)
  : concrete_widget(NULL)
{
}

template <class Widget>
InputMapIndicatorWidgetAbstractor<Widget>::
InputMapIndicatorWidgetAbstractor(Widget *concrete_widget_init)
  : concrete_widget(NULL)
{
  set_widget(concrete_widget_init);
}

template <class Widget>
QWidget *
InputMapIndicatorWidgetAbstractor<Widget>::widget(void) {
  return concrete_widget;
}

template <class Widget>
void
InputMapIndicatorWidgetAbstractor<Widget>::set_widget(Widget *new_widget) {
  concrete_widget = new_widget;
}

template <class Widget>
void
InputMapIndicatorWidgetAbstractor<Widget>::setCurrentItem(int index) {
  concrete_widget->setCurrentItem(index);
}

template <class Widget>
void
InputMapIndicatorWidgetAbstractor<Widget>::
insertItem(const QString &label, int index) {
  concrete_widget->insertItem(label, index);
}


template <class Widget>
CandidateWindowWidgetAbstractor<Widget>::CandidateWindowWidgetAbstractor(void)
  : concrete_widget(NULL)
{
}

template <class Widget>
CandidateWindowWidgetAbstractor<Widget>::
CandidateWindowWidgetAbstractor(Widget *widget_init) {
  set_widget(widget_init);
}

template <class Widget>
QWidget *
CandidateWindowWidgetAbstractor<Widget>::widget(void) {
  return concrete_widget;
}

template <class Widget>
void
CandidateWindowWidgetAbstractor<Widget>::set_widget(Widget *new_widget) {
  concrete_widget = new_widget;
}

template <class Widget>
void
CandidateWindowWidgetAbstractor<Widget>::clear(void) {
  concrete_widget->clear();
}

template <class Widget>
void
CandidateWindowWidgetAbstractor<Widget>::insertItem(const QString &item) {
  concrete_widget->insertItem(item);
}

template <class Widget>
void
CandidateWindowWidgetAbstractor<Widget>::setCurrentItem(int index) {
  concrete_widget->setCurrentItem(index);
}

template <class Widget>
void
CandidateWindowWidgetAbstractor<Widget>::setTopItem(int index) {
  concrete_widget->setTopItem(index);
}

template <class Widget>
void
CandidateWindowWidgetAbstractor<Widget>::setBottomItem(int index) {
  concrete_widget->setBottomItem(index);
}

template <class Widget>
int
CandidateWindowWidgetAbstractor<Widget>::index(const QListBoxItem *item) {
  return concrete_widget->index(item);
}


#endif  //IMKIT_IMWIDGET_STD_H
